<p align="center">
  <img src="https://github.com/kadir014/kadir014.github.io/blob/master/assets/Heat2D%20Logo.png"><br>
  <img src="https://img.shields.io/badge/python-3%2B-green.svg">
  <img src="https://img.shields.io/badge/pygame-1.9.6%2B-green.svg">
  <img src="https://img.shields.io/badge/license-GPL%203.0-blue.svg">
  <img src="https://img.shields.io/badge/status-alpha-red.svg">
</p>

---
Heat2D is a simple and concise 2D game engine. The main purpose of the engine is to simplify and speed-up the process of game development by providing purposive and useful tools and libraries.

Heat2D is easy to use, you can access [the documentation here](https://kadir014.github.io/projects/heat2d/index.html). You can use the API Reference, or read the getting started page and tutorials if you are a beginner.

## Table of Contents
- [Features](#features)
- [Documentation](#documentation)
- [License](#license)

## Features
Some of the main features Heat2D provides are
- Stage Management
- Sprites & Animation
- Easy Input Handling
- User Interface Tools
- Extra Handy Libraries

## Documentation
You can access [the documentation here](https://kadir014.github.io/projects/heat2d/index.html)

## License
[GPL 3.0](LICENSE) © Kadir Aksoy
